Constraint

Enum Constraint 

pub enum Constraint {
    Fixed(u16),
    Percentage(f32),
    Min(u16),
    Max(u16),
    Ratio(u32, u32),
    Fill,
    FitContent,
    FitContentBounded {
        min: u16,
        max: u16,
    },
    FitMin,
}
A constraint on the size of a layout area.

Variants



Fixed(u16)

An exact size in cells.



Percentage(f32)

A percentage of the total available size (0.0 to 100.0).



Min(u16)

A minimum size in cells.



Max(u16)

A maximum size in cells.



Ratio(u32, u32)

A ratio of the total available space (numerator, denominator).



Fill

Fill remaining space (like Min(0) but semantically clearer).



FitContent

Size to fit content using widget’s preferred size from LayoutSizeHint.

When used with Flex::split_with_measurer, the measurer callback provides the size hints. Defaults to zero size if no measurer is provided.



FitContentBounded

Fit content but clamp to explicit bounds.

The allocated size will be between min and max, using the widget’s preferred size when within range.

Fields

min: u16

Minimum allocation regardless of content size.

max: u16

Maximum allocation regardless of content size.



FitMin

Use widget’s minimum size (shrink-to-fit).

Allocates only the minimum space the widget requires.