WorkspaceValidationError

Enum WorkspaceValidationError 

pub enum WorkspaceValidationError {
    UnsupportedVersion {
        found: u16,
        expected: u16,
    },
    PaneTreeVersionMismatch {
        found: u16,
        expected: u16,
    },
    PaneTreeInvalid {
        issue_count: usize,
        first_issue: String,
    },
    ActivePaneNotFound {
        pane_id: PaneId,
    },
    ActivePaneNotLeaf {
        pane_id: PaneId,
    },
    EmptyWorkspaceName,
    TimelineCursorOutOfRange {
        cursor: usize,
        len: usize,
    },
    TimelineReplayFailed {
        reason: String,
    },
    TimelineReplayMismatch {
        pane_tree_hash: u64,
        replay_hash: u64,
    },
    PaneModel(PaneModelError),
}
Errors from workspace validation.

Variants



UnsupportedVersion

Schema version is not supported.

Fields

found: u16
expected: u16


PaneTreeVersionMismatch

Pane tree schema version mismatch.

Fields

found: u16
expected: u16


PaneTreeInvalid

Pane tree has structural invariant violations.

Fields

issue_count: usize
first_issue: String


ActivePaneNotFound

Active pane ID does not exist in the tree.

Fields

pane_id: PaneId


ActivePaneNotLeaf

Active pane is a split node, not a leaf.

Fields

pane_id: PaneId


EmptyWorkspaceName

Workspace name is empty.



TimelineCursorOutOfRange

Timeline cursor is outside the recorded history bounds.

Fields

cursor: usize
len: usize


TimelineReplayFailed

Timeline replay failed (missing/invalid baseline or invalid operation).

Fields

reason: String


TimelineReplayMismatch

Timeline replay does not match the persisted pane tree state.

Fields

pane_tree_hash: u64
replay_hash: u64


PaneModel(PaneModelError)

Pane model error from tree operations.