migrate_workspace

Function migrate_workspace 

pub fn migrate_workspace(
    snapshot: WorkspaceSnapshot,
) -> Result<MigrationResult, WorkspaceMigrationError>
Attempt to migrate a workspace snapshot to the current schema version.

For v1 (current), this is a no-op identity migration. Future versions will chain migrations through each intermediate version.