pub struct GridLayout { /* private fields */ }Expand description
Result of solving a grid layout.
Implementations
Sourceimpl GridLayout
impl GridLayout
Sourcepub fn cell(&self, row: usize, col: usize) -> Rect
pub fn cell(&self, row: usize, col: usize) -> Rect
Get the rectangle for a specific cell.
Returns an empty Rect if coordinates are out of bounds.
Sourcepub fn span(
&self,
row: usize,
col: usize,
rowspan: usize,
colspan: usize,
) -> Rect
pub fn span( &self, row: usize, col: usize, rowspan: usize, colspan: usize, ) -> Rect
Get the rectangle for a spanning region.
The region starts at (row, col) and spans rowspan rows and colspan columns.
Sourcepub fn area(&self, name: &str) -> Option<Rect>
pub fn area(&self, name: &str) -> Option<Rect>
Get the rectangle for a named area.
Returns None if the area name is not defined.
Sourcepub fn row_height(&self, row: usize) -> u16
pub fn row_height(&self, row: usize) -> u16
Get the height of a specific row.